@@ -1,5 +1,5 @@
 # ************************************************************************* 
-# Copyright (c) 2014-2015, SUSE LLC
+# Copyright (c) 2014-2020, SUSE LLC
 # 
 # All rights reserved.
 # 
@@ -46,11 +46,11 @@ App::CELL::Guide - Introduction to App::CELL (POD-only module)
 
 =head1 VERSION
 
-Version 0.221
+Version 0.223
 
 =cut
 
-our $VERSION = '0.221';
+our $VERSION = '0.223';
 
 
 
@@ -65,7 +65,7 @@ our $VERSION = '0.221';
 L<App::CELL> is the Configuration, Error-handling, Localization, and
 Logging (CELL) framework for applications written in Perl. In the
 L</APPROACH> section, this Guide describes the CELL approach to each of
-these four areas, separately. Then, in the </RATIONALE> section,
+these four areas, separately. Then, in the L</RATIONALE> section,
 it presents the author's reasons for bundling them together.
 
 
@@ -73,8 +73,8 @@ it presents the author's reasons for bundling them together.
 =head1 HISTORY
 
 CELL was written by Smithfarm in 2013 and 2014, initially as part of the
-Dochazka project [[ link to SourceForge ]]. Due to its generic nature, it
-was spun off into a separate project.
+L<App::Dochazka::REST> project. Due to its generic nature, it was spun off into
+a separate project.
 
 
 
@@ -244,7 +244,7 @@ the sitedir for files matching this description, and attempts to load them.
 
 =head4 Core parameters
 
-As in Request Tracker, C<core> paramters have immutable values and are
+As in Request Tracker, C<core> parameters have immutable values and are
 intended to be used as "factory defaults", set by the developer, that the
 site administrator can override by setting site parameters. If the
 application is called FooApp, its core configuration settings could be
@@ -756,7 +756,7 @@ starting with C<CELL_>.
 
 =head2 Mutable and immutable parameters
 
-It is important to realize that, although core parameters can be overriden
+It is important to realize that, although core parameters can be overridden
 by site parameters, internally the values of both are immutable. Although
 it is possible to change them by cheating, the 'set' method of C<$core> and
 C<$site> will refuse to change the value of an existing core/site parameter.
